Re: [PATCH 2/2] backlight: arcxcnn: add "arctic" vendor prefix

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



Hello

On 6/24/19 11:05 PM, Brian Dodge wrote:
The original patch adding this driver and DT bindings improperly
used "arc" as the vendor-prefix. This adds "arctic" which is the
proper prefix and retains "arc" to allow existing users of the
"arc" prefix to update to new kernels. There is at least one
(Samsung Chromebook Plus)

Signed-off-by: Brian Dodge <bdodge09@xxxxxxxxx>
---
  drivers/video/backlight/arcxcnn_bl.c | 35 +++++++++++++++++++++++++----------
  1 file changed, 25 insertions(+), 10 deletions(-)

diff --git a/drivers/video/backlight/arcxcnn_bl.c b/drivers/video/backlight/arcxcnn_bl.c
index 7b1c0a0..14c67f2 100644
--- a/drivers/video/backlight/arcxcnn_bl.c
+++ b/drivers/video/backlight/arcxcnn_bl.c
@@ -1,9 +1,9 @@
  // SPDX-License-Identifier: GPL-2.0-only
  /*
- * Backlight driver for ArcticSand ARC_X_C_0N_0N Devices
+ * Backlight driver for pSemi (formerly ArcticSand) ARC_X_C_0N_0N Devices
   *
  * Copyright 2016 ArcticSand, Inc.
  * Author : Brian Dodge <bdodge@xxxxxxxxxxxxxx>
   */
#include <linux/backlight.h>
@@ -191,27 +191,40 @@ static void arcxcnn_parse_dt(struct arcxcnn *lp)
  	if (ret == 0)
  		lp->pdata->initial_brightness = prog_val;
- ret = of_property_read_u32(node, "arc,led-config-0", &prog_val);
+	ret = of_property_read_u32(node, "arctic,led-config-0", &prog_val);
+	if (ret)
+		ret = of_property_read_u32(node, "arc,led-config-0", &prog_val);
Can you add new lines between these and all below
  	if (ret == 0)
  		lp->pdata->led_config_0 = (u8)prog_val;
- ret = of_property_read_u32(node, "arc,led-config-1", &prog_val);
+	ret = of_property_read_u32(node, "arctic,led-config-1", &prog_val);
+	if (ret)
+		ret = of_property_read_u32(node, "arc,led-config-1", &prog_val);
  	if (ret == 0)
  		lp->pdata->led_config_1 = (u8)prog_val;
- ret = of_property_read_u32(node, "arc,dim-freq", &prog_val);
+	ret = of_property_read_u32(node, "arctic,dim-freq", &prog_val);
+	if (ret)
+		ret = of_property_read_u32(node, "arc,dim-freq", &prog_val);
  	if (ret == 0)
  		lp->pdata->dim_freq = (u8)prog_val;
- ret = of_property_read_u32(node, "arc,comp-config", &prog_val);
+	ret = of_property_read_u32(node, "arctic,comp-config", &prog_val);
+	if (ret)
+		ret = of_property_read_u32(node, "arc,comp-config", &prog_val);
  	if (ret == 0)
  		lp->pdata->comp_config = (u8)prog_val;
- ret = of_property_read_u32(node, "arc,filter-config", &prog_val);
+	ret = of_property_read_u32(node, "arctic,filter-config", &prog_val);
+	if (ret)
+		ret = of_property_read_u32(node,
+				"arc,filter-config", &prog_val);
  	if (ret == 0)
  		lp->pdata->filter_config = (u8)prog_val;
- ret = of_property_read_u32(node, "arc,trim-config", &prog_val);
+	ret = of_property_read_u32(node, "arctic,trim-config", &prog_val);
+	if (ret)
+		ret = of_property_read_u32(node, "arc,trim-config", &prog_val);
  	if (ret == 0)
  		lp->pdata->trim_config = (u8)prog_val;
@@ -381,6 +394,8 @@ static int arcxcnn_remove(struct i2c_client *cl)
  }
static const struct of_device_id arcxcnn_dt_ids[] = {
+	{ .compatible = "arctic,arc2c0608" },
+	/* here to remaim compatible with an older binding, do not use */

s/remaim/remain


  	{ .compatible = "arc,arc2c0608" },
  	{ }
  };
@@ -404,5 +419,5 @@ static struct i2c_driver arcxcnn_driver = {
  module_i2c_driver(arcxcnn_driver);
MODULE_LICENSE("GPL v2");
-MODULE_AUTHOR("Brian Dodge <bdodge@xxxxxxxxxxxxxx>");
+MODULE_AUTHOR("Brian Dodge <bdodge@xxxxxxxxx>");
  MODULE_DESCRIPTION("ARCXCNN Backlight driver");
@@ -1,9 +1,9 @@
   *
- * Copyright 2016 ArcticSand, Inc.
- * Author : Brian Dodge <bdodge@xxxxxxxxxxxxxx>
+ * Copyright 2016-2019  pSemi, Inc.
+ * Author : Brian Dodge <bdodge@xxxxxxxxx>
   */
#include <linux/backlight.h>
_______________________________________________
dri-devel mailing list
dri-devel@xxxxxxxxxxxxxxxxxxxxx
https://lists.freedesktop.org/mailman/listinfo/dri-devel




[Index of Archives]     [Linux DRI Users]     [Linux Intel Graphics]     [Linux USB Devel]     [Video for Linux]     [Linux Audio Users]     [Yosemite News]     [Linux Kernel]     [Linux SCSI]     [XFree86]     [Linux USB Devel]     [Video for Linux]     [Linux Audio Users]     [Linux Kernel]     [Linux SCSI]     [XFree86]
  Powered by Linux